@@ -2,6 +2,8 @@
 import esypro
 sfs = esypro.ScriptResultManager('zqf',locals(), version=0)
 import torch
+import logging
+logging.basicConfig(level=logging.INFO, format='%(asctime)s - %(levelname)s - %(message)s')
 
 # 如果有esyimg就导入esyimg，否则导入tqdm
 rich_tqdm_available = False
@@ -14,7 +16,7 @@ except ImportError:
 
 class TrainningProcess:
     rich_tqdm_available = rich_tqdm_available
-    def __init__(self, result_dir:esypro.MyPath|str, val_index=0, device='cuda:0'):
+    def __init__(self, result_dir, val_index=0, device='cuda:0'):
         if isinstance(result_dir, str):
             self.result_dir = esypro.MyPath(result_dir)
         
@@ -22,13 +24,13 @@ class TrainningProcess:
         self.device = device
         self.result_dir = result_dir.ensure()
     
-    def continue_train_of(self, result_dir:esypro.MyPath|str):
+    def continue_train_of(self, result_dir):
         # 复制result_dir下的所有文件到self.result_dir下
         import shutil
         shutil.copytree(result_dir, self.result_dir, dirs_exist_ok=True)
     
-    def init_dataset(self, record:dict=None):
-        
+    def init_dataset(self, record=None):
+
         if not self.result_dir.cat('dataset.pth').exist():
             
             from .basic import Dataset
@@ -51,7 +53,7 @@ class TrainningProcess:
             
         return total_dataset, trainset, valset, train_loader, val_loader
     
-    def init_model(self, record:dict=None):
+    def init_model(self, record=None):
         
         from .blocks import FullConnectedLayer
         model = FullConnectedLayer(10, 10).to(self.device)
@@ -59,8 +61,6 @@ class TrainningProcess:
         if self.result_dir.cat('model_last.pth').exist():
             model.load_state_dict(torch.load(self.result_dir.cat('model_last.pth'), weights_only=True, map_location=self.device))
         
-        torch.save(model.state_dict(), self.result_dir.cat('model_last.pth'))
-        
         if record is not None:
             record['model'] = model
         
@@ -101,6 +101,8 @@ class TrainningProcess:
     
     def after_batch(self, record):
         description = self.after_batch_description(record)
+        # insert description into log using logging
+        logging.info(description)
         if self.rich_tqdm_available:
             progress.update(progress.task_ids[-1], description=description)
         else:
